#
# spec file for package python-pytaglib
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%{?sle15_python_module_pythons}
Name:           python-pytaglib
Version:        2.1.0
Release:        1.6
Summary:        Metadata "tagging" library based on TagLib
License:        GPL-3.0-only OR MIT
URL:            https://github.com/supermihi/pytaglib
Source:         https://github.com/supermihi/pytaglib/archive/v%{version}.tar.gz
# PATCH-FIX-UPSTREAM https://github.com/supermihi/pytaglib/pull/123
Patch1:         upgrade_taglib_version.patch
BuildRequires:  %{python_module Cython}
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools >= 61.0.0}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  libtag-devel
BuildRequires:  python-rpm-macros
Requires:       python-setuptools
Requires(post): update-alternatives
Requires(postun): update-alternatives
%python_subpackages

%description
pytaglib is an audio metadata (“tag”) library for Python.
It relies on the TagLib C++ library.

%prep
%autosetup -N -n "pytaglib-%{version}"
%if %{pkg_vcmp libtag-devel >= 2}
%autopatch -p1 1
%endif
# Remove pre-generated source
rm -vf src/taglib.cpp
sed -i -e "1d" src/pyprinttags.py

%build
export PYTAGLIB_CYTHONIZE=1
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitearch}
%python_clone -a %{buildroot}%{_bindir}/pyprinttags

%check
export LANG=en_US.UTF-8
%pytest_arch

%post
%python_install_alternative pyprinttags

%postun
%python_uninstall_alternative pyprinttags

%files %{python_files}
%license LICENSE.txt
%doc README.md
%{python_sitearch}/taglib*.so
%{python_sitearch}/pyprinttags.*
%{python_sitearch}/pytaglib-%{version}.dist-info/
%pycache_only %{python_sitearch}/__pycache__/pyprinttags.*
%python_alternative %{_bindir}/pyprinttags

%changelog
* Fri Mar  1 2024 Jaime Marquínez Ferrándiz <jaime.marquinez.ferrandiz@fastmail.net>
- version update to 2.1.0
  * Fix #110 (broken test) in #113
  * CI: update cibuildwheel; ensure Python-3.12 builds in #116
  * Modernize tooling in #117
- version update to 2.0.0
  * improve build_taglib.py helper script (now supports all platforms)
  * add taglib_version() to the taglib module
  * allow using File as a context manager, optionally saving on exit
  * new property File.is_closed
  * fix #94: Accept os.PathLike in constructor
  * File.path is now a Path object
- Add upgrade_taglib_version.patch
- Skip building for python 3.6 on Leap since it now uses a pyproject.toml
* Thu Oct  6 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Version Update to pytaglib 1.5.0 (2021-12-18)
  * fix #93: publish PyPI packages from GitLab workflow
  * fix #92: build windows binary wheels from CI
  * fix #89: remove Python 2 support
  * fix #88: rename pyprinttags3 --> pyprinttags, ignore unsupported tags in the script
* Wed Dec  8 2021 pgajdos@suse.com
- do not require pytest-runner for build, it is not needed
* Mon Mar 23 2020 pgajdos@suse.com
- version update to 1.4.6
  - fix #65: use tox for testing. Request re-cythonizing module with environment variable `PYTAGLIB_CYTHONIZE` instead of argument to `setup.py` now.
  - fix #63: python2 tests did not pass
  - fix #62: pyprinttags module did not work
- deleted patches
  - python-pytaglib-python2-localpath.patch (upstreamed)
* Mon Oct 14 2019 Matej Cepl <mcepl@suse.com>
- Replace %%fdupes -s with plain %%fdupes; hardlinks are better.
* Thu May  9 2019 pgajdos@suse.com
- version update to 1.4.5
  * Fix published taglib.cpp
  * Remove cython dependency from setup.py
- added patches
  fix  'LocalPath'object has no attribute 'endswith' for python2
  + python-pytaglib-python2-localpath.patch
* Wed Aug  8 2018 jsikes@suse.de
- Update to 1.4.3
  * Fix accidental upload of the Windows version to PyPI. Hopefully fixes #42, #43.
  * Fix #31: Don't use precompiled taglib.cpp on Windows
* Fri May 26 2017 jengelh@inai.de
- Ensure neutrality of description.
* Sat May 20 2017 aloisio@gmx.com
- Initial package (1.4.1)
